timeseries.Signal — GDA Toolbox v1.0 Manual

# timeseries.Signal

class `timeseries.` `Signal`(values, times=None)

  `Signal.feature`([index]) | return the region of a feature, with vertical displacement threshold tau.
  `Signal.feature_match`(other[, sigma, num_samples]) |
  `Signal.from_pointcloud`(points, direction, norm) |
  `Signal.gap`() | Return the largest homology.
  `Signal.height_measure`([sigma, num_samples, …]) | Use a simulation to estimate the height-measure of an interval.
  `Signal.interval_height`(interval) | the indicator-persistence function for intervals, called h_U(A) in the notes.
  `Signal.iter_features`([min_pers, depth_first]) | walk the feature tree.
  `Signal.iter_intervals`() | return the itertools combinations iterator over all sub-intervals.
  `Signal.iter_windows_by_index`(window[, step, …]) | Produce equal-length Signals using a sliding-window on self.
  `Signal.jagged`([beta]) | call `timeseries.jagged()` on this `Signal`’s own persistence diagram.
  `Signal.make_pers`() |
  `Signal.normalize`() | change this Signal object to have mean = 0 and max-min = 1
  `Signal.plot`(canvas[, title]) | Plot the Signal.
  `Signal.profile`(arch[, normalize, norm]) | produce profile by dragging an archetype across self, looking for matches.
  `Signal.sample_near`([sigma]) | return a Signal object that is L2-near self in the normal distribution.
  `Signal.self_similarity`(window[, step, …]) | Compare sliding windows of this Signal using a distance function.
  `Signal.smoothen`(beta) |

#### Previous topic

timeseries

#### Next topic

timeseries.Signal.feature